import pulumi
import pulumi.runtime

from ... import tables

class ObjectReference(pulumi.CustomResource):
    """
    ObjectReference contains enough information to let you inspect or modify the referred object.
    """
    def __init__(self, __name__, __opts__=None, field_path=None, name=None, namespace=None, resource_version=None, uid=None):
        if not __name__:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(__name__, str):
            raise TypeError('Expected resource name to be a string')
        if __opts__ and not isinstance(__opts__, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        __props__['apiVersion'] = 'core/v1'
        __props__['kind'] = 'ObjectReference'
        __props__['fieldPath'] = field_path
        __props__['name'] = name
        __props__['namespace'] = namespace
        __props__['resourceVersion'] = resource_version
        __props__['uid'] = uid

        super(ObjectReference, self).__init__(
            "kubernetes:core/v1:ObjectReference",
            __name__,
            __props__,
            __opts__)

    def translate_output_property(self, prop: str) -> str:
        return tables._CASING_FORWARD_TABLE.get(prop) or prop

    def translate_input_property(self, prop: str) -> str:
        return tables._CASING_BACKWARD_TABLE.get(prop) or prop



import pulumi
import pulumi.runtime

from ... import tables

class DeleteOptions(pulumi.CustomResource):
    """
    DeleteOptions may be provided when deleting an API object.
    """
    def __init__(self, __name__, __opts__=None, grace_period_seconds=None, orphan_dependents=None, preconditions=None, propagation_policy=None):
        if not __name__:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(__name__, str):
            raise TypeError('Expected resource name to be a string')
        if __opts__ and not isinstance(__opts__, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        __props__['apiVersion'] = 'v1'
        __props__['kind'] = 'DeleteOptions'
        __props__['gracePeriodSeconds'] = grace_period_seconds
        __props__['orphanDependents'] = orphan_dependents
        __props__['preconditions'] = preconditions
        __props__['propagationPolicy'] = propagation_policy

        super(DeleteOptions, self).__init__(
            "kubernetes:core/v1:DeleteOptions",
            __name__,
            __props__,
            __opts__)

    def translate_output_property(self, prop: str) -> str:
        return tables._CASING_FORWARD_TABLE.get(prop) or prop

    def translate_input_property(self, prop: str) -> str:
        return tables._CASING_BACKWARD_TABLE.get(prop) or prop



import pulumi
import pulumi.runtime

from ... import tables

class APIResourceList(pulumi.CustomResource):
    """
    APIResourceList is a list of APIResource, it is used to expose the name of the resources
    supported in a specific group and version, and if the resource is namespaced.
    """
    def __init__(self, __name__, __opts__=None, group_version=None, resources=None):
        if not __name__:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(__name__, str):
            raise TypeError('Expected resource name to be a string')
        if __opts__ and not isinstance(__opts__, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        __props__['apiVersion'] = 'v1'
        __props__['kind'] = 'APIResourceList'
        if not groupVersion:
            raise TypeError('Missing required property groupVersion')
        __props__['groupVersion'] = group_version
        if not resources:
            raise TypeError('Missing required property resources')
        __props__['resources'] = resources

        super(APIResourceList, self).__init__(
            "kubernetes:core/v1:APIResourceList",
            __name__,
            __props__,
            __opts__)

    def translate_output_property(self, prop: str) -> str:
        return tables._CASING_FORWARD_TABLE.get(prop) or prop

    def translate_input_property(self, prop: str) -> str:
        return tables._CASING_BACKWARD_TABLE.get(prop) or prop
